#!/bin/bash

# Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-base
#
# le-base is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script is included in others scripts to use common functions

PREFIX=$(dirname $(readlink -f $0))
TMP=~c3sl/tmp

getPrimaryDisk()
{
    basename $(ls -l /dev/disk/by-id/ | egrep -v "usb|total" |
        awk '{print $NF}' | sort | head -n1)
}

getDiskSize()
{
    echo $(cat /sys/block/$DEVICE/size)
}

getInitFreeSpace()
{
    echo $((
        $(tail -n1 $TMP/partition-struct | cut -d ' ' -f4 | tr "," " ") +
        $(tail -n1 $TMP/partition-struct | cut -d ' ' -f8 | tr "," " ") +
        2048))
}

getFreeSpace()
{
    size=$(cat /sys/block/$DEVICE/size)

    echo $(($size - $(getInitFreeSpace) - 5103))
}
nextPartition()
{
    next=$(($(tail -n1 $TMP/partition-struct | cut -d ' ' -f1 | sed -r \
    's@/dev/[a-z]{3}@@g')+1))

    echo $(tail -n1 $TMP/partition-struct | cut -d ' ' -f1 | sed -e \
        "s@[0-9]@$next@g")
}

getLogicalSize()
{
    echo $(grep "Id= 5" $TMP/partition-struct | awk '{print $6}' | tr "," " ")
}

saveImg()
{
    sfdisk -d /dev/$DEVICE > $TMP/partition-struct

    dd if=/dev/${DEVICE}1 of=$TMP/${DEVICE}1-$DISTRO.img
}

checkStatus()
{
    if [ -n "$(grep "$DEVICE" /etc/mtab)" ]; then
        echo "Error: /dev/$DEVICE is mounted according with mtab"
        return 1
    fi

    return 0
}

checkUser()
{
    if ! [ -r /dev/$DEVICE ]; then
        echo "Please, execute this script as root!"
        return 1
    fi
    return 0
}
