#!/bin/bash

# Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-base
#
# le-base is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This Script will partition and copy the Linux Educacional image to hard disk
# of computer

. $(dirname $(readlink -f $0))/common.sh

#------------------------------------------------------------------------------
# Sets configuration variables

if [ -n "$1" ]; then
    DEVICE=$1
else
    DEVICE=$(getPrimaryDisk)
fi

#------------------------------------------------------------------------------
# Check ambient integrity

checkUser || exit 1
checkStatus || exit 2

#------------------------------------------------------------------------------
# installs distro

if [ -e "$TMP/partition-struct" ]; then
    cp -f $TMP/partition-struct $TMP/partition-struct.tmp
    sed -i "s@$(getLogicalSize)@$(($(getLogicalSize)+$(getFreeSpace)+2048))@g"\
        $TMP/partition-struct
    echo "$(nextPartition) : start= $(getInitFreeSpace),"\
        " size=$(getFreeSpace), Id=83" >> $TMP/partition-struct
    sfdisk --force /dev/$DEVICE < $TMP/partition-struct
    mv -f $TMP/partition-struct.tmp $TMP/partition-struct

    mkfs.ext4 $(nextPartition)
    mkfs.ext4 $(grep "Id=83$" $TMP/partition-struct | cut -d ' ' -f1)
    mkswap $(grep "Id=82" $TMP/partition-struct | cut -d ' ' -f1)

    echo "Copying image to disk..."
    dd if="$(ls $TMP/*.img | grep ${DEVICE}1)" of="/dev/${DEVICE}1"
else
    echo "Not found hard disk image."
    exit 1
fi

#------------------------------------------------------------------------------
# Configures recovery partition

echo "Configurating Recovery image..."

mkdir -p $TMP/recovery
mount -t ext4 $(grep "Id=83$" $TMP/partition-struct | cut -d ' ' -f1) $TMP/recovery
gzip -c "$(ls $TMP/*.img | grep ${DEVICE}1)" > $TMP/recovery/recovery.img.gz

umount $TMP/recovery && rm -rf $TMP/recovery

#------------------------------------------------------------------------------
# Move home content to separate partition and configures fstab

echo "Configurating home directory..."

mkdir -p $TMP/chroot-dir $TMP/home
mount -t ext4 /dev/${DEVICE}1 $TMP/chroot-dir
mount -t ext4 $(nextPartition) $TMP/home

grep -v "/home" $TMP/chroot-dir/etc/fstab > $TMP/fstab.tmp && mv -f \
    $TMP/fstab.tmp $TMP/chroot-dir/etc/fstab
echo "UUID=$(ls -l --time-style="+%F %R" /dev/disk/by-uuid |
    grep $(basename $(nextPartition)) | awk '{print $8}') /home ext4 "\
    "defaults 0 0" >> $TMP/chroot-dir/etc/fstab

mv -f $TMP/chroot-dir/home/.directory $TMP/home/
for home in $(grep "home/.*/sh" $TMP/chroot-dir | cut -d':' -f6); do
    mkdir -p $TMP$home
done

umount $TMP/chroot-dir
umount $TMP/home
rm -rf $TMP/chroot-dir $TMP/home

exit 0
